from time import sleep

def typewriter(texto):
  for letra in texto:
    print(letra, flush=True, end="")
    sleep(0.05)
  print()

if __name__ == "__main__":
  texto = "testando 123"
  typewriter(texto)


from setuptools import setup, find_packages

with open("README.md", "r") as arq:
    readme = arq.read()

setup(name='print_utilities',
    version='0.0.2',
    license='MIT License',
    author='CarlosAllberto',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='dasilvacarlosalberto344@gmail.com',
    keywords='print utilities',
    description='Uma biblioteca com varias utilidades para printar',
    packages=find_packages(),)